Quantcast

Add more info for the new recipes in 3.08 (ty adys). Update the custom strings to be more... proper.

ackis [01-14-09 - 18:56]
Add more info for the new recipes in 3.08 (ty adys).  Update the custom strings to be more... proper.
Filename
Locals/ARLLocals-enUS.lua
RecipeDB/ARL-Alchemy.lua
RecipeDB/ARL-Blacksmith.lua
RecipeDB/ARL-Enchant.lua
RecipeDB/ARL-Leatherwork.lua
diff --git a/Locals/ARLLocals-enUS.lua b/Locals/ARLLocals-enUS.lua
index 7be560a..6f0d1d9 100644
--- a/Locals/ARLLocals-enUS.lua
+++ b/Locals/ARLLocals-enUS.lua
@@ -329,30 +329,30 @@ L["Custom9"] = "Recipe is created by Engineers."
 L["Custom10"] = "Quest to obtain the recipe opens up after turning in the Head of Onyxia."
 L["Custom11"] = "Obtained by clicking on a tablet in Zul'Gurub in the Edge of Madness."
 L["Custom12"] = "Discovered by doing transmutes using Wrath of the Lich King ingredients."
-L["Custom13"] = "Goldthorn Tea Henry Stern."
-L["Custom14"] = "Minor Inscription Research."
-L["Custom15"] = "Northrend Inscription Research."
-L["Custom16"] = "EngineeringRenewalReward."
+L["Custom13"] = "Obtained by talking to Henry Stern in Razorfen Downs."
+L["Custom14"] = "Obtained randomly by conducting minor inscription research."
+L["Custom15"] = "Obtained randomly by conducting Northrend inscription research."
+L["Custom16"] = "Obtained randomly by renewing your engineering membership."
 L["Custom17"] = "The schematic can be found on the floor near Golem Lord Argelmach in Blackrock Depths. Only engineers with 300 skill may learn the schematic after clicking on it."
-L["Custom18"] = "Northrend Alchemy Research."
-L["Custom19"] = "Northrend Transmute."
-L["Custom20"] = "Goblin transport."
-L["Custom21"] = "Gnome transport."
+L["Custom18"] = "Obtained randomly by conducting Northrend alchemy research."
+L["Custom19"] = "Discovered by doing transmutes using Northrend or higher ingredients (transmute tooltip mentions that there is a chance to discovery something)."
+L["Custom20"] = "Goblin transport." -- Update
+L["Custom21"] = "Gnome transport." -- Update
 L["Custom22"] = "Random BoP drop off of bosses in AQ40."
-L["Custom23"] = "DM Cache - Knot Thimblejack"
-L["Custom24"] = "Sunwell Trash Drop"
+L["Custom23"] = "Randomly obtained in Dire Maul (North) in Knot Thimblejack's cache."
+L["Custom24"] = "Random Sunwell trash drop."
 L["Custom25"] = "There is a chance that you find it in 5 different rooms in blackrock depths, its random spawn though, and sometimes it doesnt even spawn at all."
-L["Custom26"] = "Molten Core Bosses"
-L["Custom27"] = "MC Duder In BWL"
-L["Custom28"] = "BT trash/bosses"
-L["Custom29"] = "ZA bosses"
-L["Custom30"] = "Jandice in Scholo book appears"
-L["Custom31"] = "Blacksmith plans in Stratholme"
-L["Custom32"] = "DM Tribute Run - Chest"
-L["Custom33"] = "World Dragons"
-L["Custom34"] = "Black Temple / Hyjal Trash Drop"
-L["Custom35"] = "Blade's Edge Mountains Summon Bosses"
-L["Custom36"] = "From a NPC in Dalaran sewers after doing The Taste Test"
+L["Custom26"] = "Random drop off of Molten Core bosses."
+L["Custom27"] = "Mind Control Master Elemental Shaper Krixix in Blackwing Lair."
+L["Custom28"] = "Random drop from Black Temple/Hyjal Summit trash/bosses."
+L["Custom29"] = "Random drop off of Zul'Aman bosses."
+L["Custom30"] = "Jandice in Scholo book appears" -- Update
+L["Custom31"] = "Blacksmith plans in Stratholme" -- Update
+L["Custom32"] = "DM Tribute Run - Chest" -- Update
+L["Custom33"] = "World Dragons" -- Update
+L["Custom34"] = "Random Black Temple / Hyjal Summit trash drop"
+L["Custom35"] = "Blade's Edge Mountains Summon Bosses" -- Update
+L["Custom36"] = "From a NPC in Dalaran sewers after doing The Taste Test" -- Update

 -- Monster/Quest/Trainer/Vendor strings:

diff --git a/RecipeDB/ARL-Blacksmith.lua b/RecipeDB/ARL-Blacksmith.lua
index 0e36032..af6fb78 100644
--- a/RecipeDB/ARL-Blacksmith.lua
+++ b/RecipeDB/ARL-Blacksmith.lua
@@ -2902,11 +2902,11 @@ function addon:InitBlacksmithing(RecipeDB)

 	if (version == "3.0.8") then

-	-- Titanium Plating -- ???
+	-- Titanium Plating -- 62202
 	recipecount = recipecount + 1
-	--self:addTradeSkill(RecipeDB,,450,44936,3,2018)
-	--self:addTradeFlags(RecipeDB,,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41,130,131)
-	--self:addTradeAcquire(RecipeDB,,6,1052,4,32565,6,1052,4,32774,6,1037,4,32564,6,1037,4,32773)
+	self:addTradeSkill(RecipeDB,62202,450,44936,3,2018)
+	self:addTradeFlags(RecipeDB,62202,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41,130,131)
+	self:addTradeAcquire(RecipeDB,62202,6,1052,4,32565,6,1052,4,32774,6,1037,4,32564,6,1037,4,32773)

 	end

diff --git a/RecipeDB/ARL-Leatherwork.lua b/RecipeDB/ARL-Leatherwork.lua
index 499124b..7f14220 100644
--- a/RecipeDB/ARL-Leatherwork.lua
+++ b/RecipeDB/ARL-Leatherwork.lua
@@ -3024,17 +3024,17 @@ function addon:InitLeatherworking(RecipeDB)

 	if (version == "3.0.8") then

-	-- Windripper Boots -- ???
+	-- Windripper Boots -- 62176
 	recipecount = recipecount + 1
-	--self:addTradeSkill(RecipeDB,,440,44930,4,2108)
-	--self:addTradeFlags(RecipeDB,,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41)
-	--self:addTradeAcquire(RecipeDB,,)
+	self:addTradeSkill(RecipeDB,62176,440,44930,4,2108)
+	self:addTradeFlags(RecipeDB,62176,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41)
+	--self:addTradeAcquire(RecipeDB,62176,)

-	-- Windripper Leggings -- ???
+	-- Windripper Leggings -- 62177
 	recipecount = recipecount + 1
-	--self:addTradeSkill(RecipeDB,,440,44931,4,2108)
-	--self:addTradeFlags(RecipeDB,,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41)
-	--self:addTradeAcquire(RecipeDB,,)
+	self:addTradeSkill(RecipeDB,62177,440,44931,4,2108)
+	self:addTradeFlags(RecipeDB,62177,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41)
+	--self:addTradeAcquire(RecipeDB,62177,)

 	end
diff --git a/RecipeDB/ARL-Alchemy.lua b/RecipeDB/ARL-Alchemy.lua
index 509a726..0373cf1 100644
--- a/RecipeDB/ARL-Alchemy.lua
+++ b/RecipeDB/ARL-Alchemy.lua
@@ -1500,23 +1500,23 @@ function addon:InitAlchemy(RecipeDB)

 	if (version == "3.0.8") then

 	-- Elixir of Water Walking -- ???
 	recipecount = recipecount + 1
-	--self:addTradeSkill(RecipeDB,,400,8827,1,2259)
-	--self:addTradeFlags(RecipeDB,,1,2,12,21,22,23,24,25,26,27,28,29,30,36,41)
-	--self:addTradeAcquire(RecipeDB,,8,18)
+	self:addTradeSkill(RecipeDB,62410,400,8827,1,2259)
+	self:addTradeFlags(RecipeDB,62410,1,2,12,21,22,23,24,25,26,27,28,29,30,36,41)
+	self:addTradeAcquire(RecipeDB,62410,8,18)

-	-- Ethereal Oil -- ???
+	-- Ethereal Oil -- 62409
 	recipecount = recipecount + 1
-	--self:addTradeSkill(RecipeDB,,395,,1, 2259)
-	--self:addTradeFlags(RecipeDB,,1,2,3,21,22,23,24,25,26,27,28,29,30,36,41)
-	--self:addTradeAcquire(RecipeDB,,1,26903,1,26951,1,26975,1,26987,1,28703)
+	self:addTradeSkill(RecipeDB,62409,395,nil,1,2259)
+	self:addTradeFlags(RecipeDB,62409,1,2,3,21,22,23,24,25,26,27,28,29,30,36,41)
+	self:addTradeAcquire(RecipeDB,62409,1,26903,1,26951,1,26975,1,26987,1,28703)

 	-- Lesser Flask of Resistance -- ??
 	recipecount = recipecount + 1
-	--self:addTradeSkill(RecipeDB,,395,44939,1, 2259)
-	--self:addTradeFlags(RecipeDB,,1,2,3,21,22,23,24,25,26,27,28,29,30,36,41)
-	--self:addTradeAcquire(RecipeDB,,1,26903,1,26951,1,26975,1,26987,1,28703)
+	self:addTradeSkill(RecipeDB,62213,395,44939,1,2259)
+	self:addTradeFlags(RecipeDB,62213,1,2,3,21,22,23,24,25,26,27,28,29,30,36,41)
+	self:addTradeAcquire(RecipeDB,62213,1,26903,1,26951,1,26975,1,26987,1,28703)

 	end
@@ -1500,23 +1500,23 @@ function addon:InitAlchemy(RecipeDB)
 	if (version == "3.0.8") then

-	-- Elixir of Water Walking -- ???
+	-- Elixir of Water Walking -- 62410
 	recipecount = recipecount + 1
@@ -1500,23 +1500,23 @@ function addon:InitAlchemy(RecipeDB)

-	-- Lesser Flask of Resistance -- ??
+	-- Lesser Flask of Resistance -- 62213
 	recipecount = recipecount + 1

diff --git a/RecipeDB/ARL-Enchant.lua b/RecipeDB/ARL-Enchant.lua
index 3533140..7d7f593 100644
--- a/RecipeDB/ARL-Enchant.lua
+++ b/RecipeDB/ARL-Enchant.lua
@@ -1758,17 +1758,17 @@ function addon:InitEnchanting(RecipeDB)

 	if (version == "3.0.8") then

 	-- Enchant Bracer - Major Stamina -- ???
 	recipecount = recipecount + 1
-	--self:addTradeSkill(RecipeDB,,440,nil,2,7411)
-	--self:addTradeFlags(RecipeDB,,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41)
-	--self:addTradeAcquire(RecipeDB,,2,32514)
+	self:addTradeSkill(RecipeDB,62256,440,nil,2,7411)
+	self:addTradeFlags(RecipeDB,62256,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41)
+	self:addTradeAcquire(RecipeDB,62256,2,32514)

 	-- Enchant Weapon - Titanguard -- ???
 	recipecount = recipecount + 1
-	--self:addTradeSkill(RecipeDB,,440,nil,2,7411)
-	--self:addTradeFlags(RecipeDB,,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41)
-	--self:addTradeAcquire(RecipeDB,,2,32514)
+	self:addTradeSkill(RecipeDB,62257,440,nil,2,7411)
+	self:addTradeFlags(RecipeDB,62257,1,2,4,21,22,23,24,25,26,27,28,29,30,36,41)
+	self:addTradeAcquire(RecipeDB,62257,2,32514)

 	end
@@ -1758,17 +1758,17 @@ function addon:InitEnchanting(RecipeDB)
 	if (version == "3.0.8") then

-	-- Enchant Bracer - Major Stamina -- ???
+	-- Enchant Bracer - Major Stamina -- 62256
 	recipecount = recipecount + 1
@@ -1758,17 +1758,17 @@ function addon:InitEnchanting(RecipeDB)

-	-- Enchant Weapon - Titanguard -- ???
+	-- Enchant Weapon - Titanguard -- 62257
 	recipecount = recipecount + 1
